# Foo

## Living Standard, 1 January 1970

This version:
  http://example.com/foo
Editor:
  Example Editor

COPYRIGHT GOES HERE

## Abstract

Testing the <l> element.

    interface Foo {
        attribute long bar;
        long baz();
    };

`el` prop

`Foo` `bar` `el` prop

    {{Foo}} {{Foo/bar}} <{el}> 'prop'
    Foo bar el prop

should fatal

`bar`

    navigator.bluetooth.baz({...});

## Index

### Terms defined by this specification

- bar, in §Unnumbered section
- baz(), in §Unnumbered section
- el, in §Unnumbered section
- Foo, in §Unnumbered section
- prop, in §Unnumbered section

https://heycam.github.io/webidl/#idl-long Referenced in:

- Unnamed section (2)

### Terms defined by reference

- [WebIDL] defines the following terms:
  - long

## References

### Normative References

[WebIDL]
  Boris Zbarsky. Web IDL. 15 December 2016. ED. URL: https://heycam.github.io/webidl/

## IDL Index

    interface Foo {
        attribute long bar;
        long baz();
    };

#foo Referenced in:

- Unnamed section (2)

#dom-foo-bar Referenced in:

- Unnamed section (2) (3)

#dom-foo-baz Referenced in:

- Unnamed section

#elementdef-el Referenced in:

- Unnamed section (2)

#propdef-prop Referenced in:

- Unnamed section (2)